"""
NPlib - A library for numerical processing.

This package provides various numerical processing utilities.
"""
from .logging_config import setup_logging

setup_logging()

__version__ = "1.0.0"
__maintainer__ = "Riccardo Farris"
__credits__ = 'Reactive Nanoparticles Laboratory'
__copyright__ = '2024'
__email__ = 'rfarris@ub.edu'
__status__ = 'Stable'
